@@ -1,9 +1,13 @@
 """
 base utils for the hubspot3 library
 """
-import requests
 import logging
-from hubspot3.globals import BASE_URL
+import sys
+from collections import OrderedDict
+from typing import Dict, Union
+
+
+PY_VERSION = sys.version_info
 
 
 class NullHandler(logging.Handler):
@@ -11,31 +15,12 @@ class NullHandler(logging.Handler):
         pass
 
 
-def get_log(name):
+def get_log(name: str):
     logger = logging.getLogger(name)
     logger.addHandler(NullHandler())
     return logger
 
 
-def auth_checker(access_token: str) -> int:
-    """Do a simple api request using the access token"""
-    url = "{}/contacts/v1/lists/all/contacts/all?count=1&offset=0&access_token={}".format(
-        BASE_URL, access_token
-    )
-    result = requests.get(url)
-    return result.status_code
-
-
-def refresh_access_token(refresh_token: str, client_id: str) -> str:
-    """Refreshes an OAuth access token"""
-    payload = "refresh_token={}&client_id={}&grant_type=refresh_token".format(
-        refresh_token, client_id
-    )
-    url = "{}/oauth/v1/token".format(BASE_URL)
-    result = requests.post(url, data=payload)
-    return result.text
-
-
 def force_utf8(raw):
     """Will force the string to convert to valid utf8"""
     string = raw
@@ -63,3 +48,13 @@ def prettify(obj_with_props, id_key):
         pass
 
     return prettified
+
+
+def ordered_dict(dictionary: Dict) -> Union[Dict, OrderedDict]:
+    """
+    shim to fix some param ordering issues with python 3.5
+    in python 3.6+, dictionaries are ordered by default
+    """
+    if PY_VERSION[0] == 3 and PY_VERSION[1] == 5:
+        return OrderedDict(sorted(dictionary.items(), key=lambda x: x[0]))
+    return dictionary
